==> ruby-domain_name-0.6.20231109-1-any.pkg.tar.xz: usr/lib/ruby/gems/3.0.0/gems/domain_name-0.6.20231109/CHANGELOG.md <==
# Change Log

## [v0.6.20231109](https://github.com/knu/ruby-domain_name/tree/v0.6.20231109) (2023-11-14)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.6.20190701...v0.6.20231109)

- Update the eTLD database to 2023-11-09 00:10:10 UTC

- Require Ruby >=2.7 and drop the dependency on unf

## [v0.5.20190701](https://github.com/knu/ruby-domain_name/tree/v0.5.20190701) (2019-07-05)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20180417...v0.5.20190701)

- Update the eTLD database to 2019-07-01 18:45:50 UTC

## [v0.5.20180417](https://github.com/knu/ruby-domain_name/tree/v0.5.20180417) (2018-04-17)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20170404...v0.5.20180417)

- Update the eTLD database to 2018-04-17T23:50:25Z

## [v0.5.20170404](https://github.com/knu/ruby-domain_name/tree/v0.5.20170404) (2017-04-04)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20170223...v0.5.20170404)

- Update the eTLD database to 2017-04-04T20:20:25Z

## [v0.5.20170223](https://github.com/knu/ruby-domain_name/tree/v0.5.20170223) (2017-02-23)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20161129...v0.5.20170223)

- Update the eTLD database to 2017-02-23T00:52:11Z

## [v0.5.20161129](https://github.com/knu/ruby-domain_name/tree/v0.5.20161129) (2016-11-29)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160826...v0.5.20161129)

- Update the eTLD database to 2016-11-29T01:22:03Z

## [v0.5.20161021](https://github.com/knu/ruby-domain_name/tree/v0.5.20161021) (2016-10-27)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160826...v0.5.20161021)

- Update the eTLD database to 2016-10-21T20:52:10Z

## [v0.5.20160826](https://github.com/knu/ruby-domain_name/tree/v0.5.20160826) (2016-09-01)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160615...v0.5.20160826)

- Update the license for the eTLD database
- Update the eTLD database to 2016-08-26T16:52:03Z

## [v0.5.20160615](https://github.com/knu/ruby-domain_name/tree/v0.5.20160615) (2016-06-16)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160310...v0.5.20160615)

- Always set `@domain` to avoid a warning when `$VERBOSE` is on
- Update the eTLD database to 2016-06-15T16:22:11Z

## [v0.5.20160310](https://github.com/knu/ruby-domain_name/tree/v0.5.20160310) (2016-03-17)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160309...v0.5.20160310)

- Update development dependencies for obsolete rubies
- Update the eTLD database to 2016-03-10T21:22:02Z

## [v0.5.20160309](https://github.com/knu/ruby-domain_name/tree/v0.5.20160309) (2016-03-09)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160216...v0.5.20160309)

- Fix support for Ruby 1.8
- Update the eTLD database to 2016-03-09T09:52:02Z

## [v0.5.20160216](https://github.com/knu/ruby-domain_name/tree/v0.5.20160216) (2016-02-24)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160128...v0.5.20160216)

- Update the eTLD database to 2016-02-16T19:22:02Z

## [v0.5.20160128](https://github.com/knu/ruby-domain_name/tree/v0.5.20160128) (2016-01-29)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.25...v0.5.20160128)

- Use the date as part of VERSION
- Update the eTLD database to 2016-01-28T23:22:02Z

## [v0.5.25](https://github.com/knu/ruby-domain_name/tree/v0.5.25) (2015-10-06)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.24...v0.5.25)

- Restrict i18n < 0.7.0 on ruby 1.8.
- Update the eTLD database to 2015-09-29T17:22:03Z

## [v0.5.24](https://github.com/knu/ruby-domain_name/tree/v0.5.24) (2015-04-16)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.23...v0.5.24)

- Update the eTLD database to 2015-04-07T20:26:05Z

## [v0.5.23](https://github.com/knu/ruby-domain_name/tree/v0.5.23) (2014-12-19)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.22...v0.5.23)

- Update the eTLD database to 2014-12-18T02:26:03Z

## [v0.5.22](https://github.com/knu/ruby-domain_name/tree/v0.5.22) (2014-10-28)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.21...v0.5.22)

- Update the eTLD database to 2014-10-27T15:26:07Z

## [v0.5.21](https://github.com/knu/ruby-domain_name/tree/v0.5.21) (2014-09-09)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20...v0.5.21)

- Update the eTLD database to 2014-09-05T01:56:10Z

## [v0.5.20](https://github.com/knu/ruby-domain_name/tree/v0.5.20) (2014-08-18)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.19...v0.5.20)

- Update the eTLD database to 2014-08-14T00:56:09Z

## [v0.5.19](https://github.com/knu/ruby-domain_name/tree/v0.5.19) (2014-06-12)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.18...v0.5.19)

- Update the eTLD database to 2014-06-11T15:26:13Z

## [v0.5.18](https://github.com/knu/ruby-domain_name/tree/v0.5.18) (2014-03-27)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.17...v0.5.18)

- Update the eTLD database to 2014-03-27T03:00:59Z

## [v0.5.17](https://github.com/knu/ruby-domain_name/tree/v0.5.17) (2014-03-21)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.16...v0.5.17)

- Update the eTLD database to 2014-03-20T15:01:09Z

## [v0.5.16](https://github.com/knu/ruby-domain_name/tree/v0.5.16) (2014-02-12)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.15...v0.5.16)

- Update the eTLD database to 2014-02-11T16:01:07Z

## [v0.5.15](https://github.com/knu/ruby-domain_name/tree/v0.5.15) (2013-11-15)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.14...v0.5.15)

- Update the eTLD database to 2013-11-15T16:01:28Z
- Merge IDN tests from mozilla-central/netwerk/test/unit/data/test_psl.txt

## [v0.5.14](https://github.com/knu/ruby-domain_name/tree/v0.5.14) (2013-10-16)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.13...v0.5.14)

- Update the eTLD database to 2013-10-16T07:01:24Z

## [v0.5.13](https://github.com/knu/ruby-domain_name/tree/v0.5.13) (2013-08-18)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.12...v0.5.13)

- Update the eTLD database to 2013-08-15T11:01:26Z
- Adjust dependencies for Ruby 1.8

## [v0.5.12](https://github.com/knu/ruby-domain_name/tree/v0.5.12) (2013-06-07)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.11...v0.5.12)

- Update the eTLD database to 2013-06-06T23:00:56Z
- Add *_idn methods that do ToUnicode conversion

## [v0.5.11](https://github.com/knu/ruby-domain_name/tree/v0.5.11) (2013-04-12)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.10...v0.5.11)

- Add DomainName#superdomain
- Update the database to 2013-04-05T23:00:49Z

## [v0.5.10](https://github.com/knu/ruby-domain_name/tree/v0.5.10) (2013-04-01)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.9...v0.5.10)

- Update the eTLD database to that of 2013-03-31T03:02:39Z

## [v0.5.9](https://github.com/knu/ruby-domain_name/tree/v0.5.9) (2013-03-17)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.8...v0.5.9)

- Support unf 0.1.0

## [v0.5.8](https://github.com/knu/ruby-domain_name/tree/v0.5.8) (2013-03-14)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.7...v0.5.8)

- Update the eTLD database to the version as of 2013-02-18T20:02:07Z

## [v0.5.7](https://github.com/knu/ruby-domain_name/tree/v0.5.7) (2013-01-07)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.6...v0.5.7)

- Update the eTLD list

## [v0.5.6](https://github.com/knu/ruby-domain_name/tree/v0.5.6) (2012-12-06)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.5...v0.5.6)

- Update the eTLD list

## [v0.5.5](https://github.com/knu/ruby-domain_name/tree/v0.5.5) (2012-12-06)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.4...v0.5.5)

- Add an optional host_only flag to DomainName#cookie_domain?
- Migrate from jeweler to bundle gem

## [v0.5.4](https://github.com/knu/ruby-domain_name/tree/v0.5.4) (2012-09-18)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.3...v0.5.4)

- Update the eTLD list
- Import updated test cases suggested by Mozilla developers

## [v0.5.3](https://github.com/knu/ruby-domain_name/tree/v0.5.3) (2012-04-06)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.2...v0.5.3)

- Implement Punycode decoder

**Closed issues:**

-  Running DomainName multi-threaded leads to Stack Errors [\#2](https://github.com/knu/ruby-domain_name/issues/2)

## [v0.5.2](https://github.com/knu/ruby-domain_name/tree/v0.5.2) (2012-01-18)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.1...v0.5.2)

- Update the eTLD list

## [v0.5.1](https://github.com/knu/ruby-domain_name/tree/v0.5.1) (2011-11-09)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.0...v0.5.1)

- DomainName.new calls #to_str if a non-string object is given
- Fix support for IPv6 addresses enclosed in square brackets

**Merged pull requests:**

- Fixed DomainName\#\<=\> for use with Ruby 1.8.7 [\#1](https://github.com/knu/ruby-domain_name/pull/1) ([drbrain](https://github.com/drbrain))

## [v0.5.0](https://github.com/knu/ruby-domain_name/tree/v0.5.0) (2011-11-04)
[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.0.0...v0.5.0)

- Implement DomainName comparison and fix cookie_domain?()
- Avoid warnings about uninitialized instance variables

## [v0.0.0](https://github.com/knu/ruby-domain_name/tree/v0.0.0) (2011-10-29)

- Initial release

\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> ruby-domain_name-0.6.20240107-3-any.pkg.tar.xz: usr/lib/ruby/gems/3.3.0/gems/domain_name-0.6.20240107/CHANGELOG.md <==
# Changelog

## [v0.6.20240107](https://github.com/knu/ruby-domain_name/tree/v0.6.20240107) (2024-01-09)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.6.20231109...v0.6.20240107)

- Update the eTLD database to 2024-01-07 11:25:45 UTC

**Closed issues:**

- git tag v0.6.20231109 is missing [\#25](https://github.com/knu/ruby-domain_name/issues/25)
- Unicode Normalization not appropriate for ASCII-8BIT [\#23](https://github.com/knu/ruby-domain_name/issues/23)

**Merged pull requests:**

- Fix regression: Allow DomainName.normalize to accept ASCII-only, non-unicode encoded input [\#27](https://github.com/knu/ruby-domain_name/pull/27) ([tisba](https://github.com/tisba))

## [v0.6.20231109](https://github.com/knu/ruby-domain_name/tree/v0.6.20231109) (2023-11-14)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20190701...v0.6.20231109)

- Require Ruby >=2.7 and drop the dependency on unf
- Update the eTLD database to 2023-11-09 00:10:10 UTC

**Closed issues:**

- "web.app" domain is not considered canonical [\#21](https://github.com/knu/ruby-domain_name/issues/21)

## [v0.5.20190701](https://github.com/knu/ruby-domain_name/tree/v0.5.20190701) (2019-07-05)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20180417...v0.5.20190701)

- Update the eTLD database to 2019-07-01 18:45:50 UTC

## [v0.5.20180417](https://github.com/knu/ruby-domain_name/tree/v0.5.20180417) (2018-04-18)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20170404...v0.5.20180417)

- Update the eTLD database to 2018-04-17T23:50:25Z

## [v0.5.20170404](https://github.com/knu/ruby-domain_name/tree/v0.5.20170404) (2017-04-06)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20170223...v0.5.20170404)

- Update the eTLD database to 2017-04-04T20:20:25Z

## [v0.5.20170223](https://github.com/knu/ruby-domain_name/tree/v0.5.20170223) (2017-02-23)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20161129...v0.5.20170223)

- Update the eTLD database to 2017-02-23T00:52:11Z

**Closed issues:**

- Changelog doesn't mention the version '0.5.20161021' [\#10](https://github.com/knu/ruby-domain_name/issues/10)

## [v0.5.20161129](https://github.com/knu/ruby-domain_name/tree/v0.5.20161129) (2016-11-29)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20161021...v0.5.20161129)

- Update the eTLD database to 2016-11-29T01:22:03Z

## [v0.5.20161021](https://github.com/knu/ruby-domain_name/tree/v0.5.20161021) (2016-10-27)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160826...v0.5.20161021)

- Update the eTLD database to 2016-10-21T20:52:10Z

## [v0.5.20160826](https://github.com/knu/ruby-domain_name/tree/v0.5.20160826) (2016-09-01)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160615...v0.5.20160826)

- Update the license for the eTLD database
- Update the eTLD database to 2016-08-26T16:52:03Z

**Closed issues:**

- Please add a changelog [\#5](https://github.com/knu/ruby-domain_name/issues/5)

## [v0.5.20160615](https://github.com/knu/ruby-domain_name/tree/v0.5.20160615) (2016-06-16)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160310...v0.5.20160615)

- Always set `@domain` to avoid a warning when `$VERBOSE` is on
- Update the eTLD database to 2016-06-15T16:22:11Z

## [v0.5.20160310](https://github.com/knu/ruby-domain_name/tree/v0.5.20160310) (2016-03-17)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160309...v0.5.20160310)

- Update development dependencies for obsolete rubies
- Update the eTLD database to 2016-03-10T21:22:02Z

## [v0.5.20160309](https://github.com/knu/ruby-domain_name/tree/v0.5.20160309) (2016-03-09)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160216...v0.5.20160309)

- Fix support for Ruby 1.8
- Update the eTLD database to 2016-03-09T09:52:02Z

## [v0.5.20160216](https://github.com/knu/ruby-domain_name/tree/v0.5.20160216) (2016-02-24)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20160128...v0.5.20160216)

- Update the eTLD database to 2016-02-16T19:22:02Z

## [v0.5.20160128](https://github.com/knu/ruby-domain_name/tree/v0.5.20160128) (2016-01-29)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.25...v0.5.20160128)

- Use the date as part of VERSION
- Update the eTLD database to 2016-01-28T23:22:02Z

## [v0.5.25](https://github.com/knu/ruby-domain_name/tree/v0.5.25) (2015-10-06)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.24...v0.5.25)

- Restrict i18n < 0.7.0 on ruby 1.8.
- Update the eTLD database to 2015-09-29T17:22:03Z

**Closed issues:**

- Bad link on rubygems.org? [\#4](https://github.com/knu/ruby-domain_name/issues/4)

## [v0.5.24](https://github.com/knu/ruby-domain_name/tree/v0.5.24) (2015-04-16)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.23...v0.5.24)

- Update the eTLD database to 2015-04-07T20:26:05Z

## [v0.5.23](https://github.com/knu/ruby-domain_name/tree/v0.5.23) (2014-12-19)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.22...v0.5.23)

- Update the eTLD database to 2014-12-18T02:26:03Z

## [v0.5.22](https://github.com/knu/ruby-domain_name/tree/v0.5.22) (2014-10-28)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.21...v0.5.22)

- Update the eTLD database to 2014-10-27T15:26:07Z

## [v0.5.21](https://github.com/knu/ruby-domain_name/tree/v0.5.21) (2014-09-09)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.20...v0.5.21)

- Update the eTLD database to 2014-09-05T01:56:10Z

## [v0.5.20](https://github.com/knu/ruby-domain_name/tree/v0.5.20) (2014-08-18)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.19...v0.5.20)

- Update the eTLD database to 2014-08-14T00:56:09Z

## [v0.5.19](https://github.com/knu/ruby-domain_name/tree/v0.5.19) (2014-06-12)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.18...v0.5.19)

- Update the eTLD database to 2014-06-11T15:26:13Z

## [v0.5.18](https://github.com/knu/ruby-domain_name/tree/v0.5.18) (2014-03-27)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.17...v0.5.18)

- Update the eTLD database to 2014-03-27T03:00:59Z

## [v0.5.17](https://github.com/knu/ruby-domain_name/tree/v0.5.17) (2014-03-21)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.16...v0.5.17)

- Update the eTLD database to 2014-03-20T15:01:09Z

## [v0.5.16](https://github.com/knu/ruby-domain_name/tree/v0.5.16) (2014-02-12)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.15...v0.5.16)

- Update the eTLD database to 2014-02-11T16:01:07Z

## [v0.5.15](https://github.com/knu/ruby-domain_name/tree/v0.5.15) (2013-11-15)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.14...v0.5.15)

- Update the eTLD database to 2013-11-15T16:01:28Z
- Merge IDN tests from mozilla-central/netwerk/test/unit/data/test_psl.txt

## [v0.5.14](https://github.com/knu/ruby-domain_name/tree/v0.5.14) (2013-10-16)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.13...v0.5.14)

- Update the eTLD database to 2013-10-16T07:01:24Z

## [v0.5.13](https://github.com/knu/ruby-domain_name/tree/v0.5.13) (2013-08-18)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.12...v0.5.13)

- Update the eTLD database to 2013-08-15T11:01:26Z
- Adjust dependencies for Ruby 1.8

## [v0.5.12](https://github.com/knu/ruby-domain_name/tree/v0.5.12) (2013-06-07)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.11...v0.5.12)

- Update the eTLD database to 2013-06-06T23:00:56Z
- Add *_idn methods that do ToUnicode conversion

## [v0.5.11](https://github.com/knu/ruby-domain_name/tree/v0.5.11) (2013-04-12)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.10...v0.5.11)

- Add DomainName#superdomain
- Update the database to 2013-04-05T23:00:49Z

## [v0.5.10](https://github.com/knu/ruby-domain_name/tree/v0.5.10) (2013-04-01)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.9...v0.5.10)

- Update the eTLD database to that of 2013-03-31T03:02:39Z

## [v0.5.9](https://github.com/knu/ruby-domain_name/tree/v0.5.9) (2013-03-17)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.8...v0.5.9)

- Support unf 0.1.0

## [v0.5.8](https://github.com/knu/ruby-domain_name/tree/v0.5.8) (2013-03-14)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.7...v0.5.8)

- Update the eTLD database to the version as of 2013-02-18T20:02:07Z

## [v0.5.7](https://github.com/knu/ruby-domain_name/tree/v0.5.7) (2013-01-07)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.6...v0.5.7)

- Update the eTLD list

## [v0.5.6](https://github.com/knu/ruby-domain_name/tree/v0.5.6) (2012-12-06)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.5...v0.5.6)

- Update the eTLD list

## [v0.5.5](https://github.com/knu/ruby-domain_name/tree/v0.5.5) (2012-12-06)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.4...v0.5.5)

- Add an optional host_only flag to DomainName#cookie_domain?
- Migrate from jeweler to bundle gem

## [v0.5.4](https://github.com/knu/ruby-domain_name/tree/v0.5.4) (2012-09-18)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.3...v0.5.4)

- Update the eTLD list
- Import updated test cases suggested by Mozilla developers

## [v0.5.3](https://github.com/knu/ruby-domain_name/tree/v0.5.3) (2012-04-06)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.2...v0.5.3)

- Implement Punycode decoder

**Closed issues:**

-  Running DomainName multi-threaded leads to Stack Errors [\#2](https://github.com/knu/ruby-domain_name/issues/2)

## [v0.5.2](https://github.com/knu/ruby-domain_name/tree/v0.5.2) (2012-01-18)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.1...v0.5.2)

- Update the eTLD list

## [v0.5.1](https://github.com/knu/ruby-domain_name/tree/v0.5.1) (2011-11-09)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.5.0...v0.5.1)

- DomainName.new calls #to_str if a non-string object is given
- Fix support for IPv6 addresses enclosed in square brackets

**Merged pull requests:**

- Fixed DomainName\#\<=\> for use with Ruby 1.8.7 [\#1](https://github.com/knu/ruby-domain_name/pull/1) ([drbrain](https://github.com/drbrain))

## [v0.5.0](https://github.com/knu/ruby-domain_name/tree/v0.5.0) (2011-11-04)

[Full Changelog](https://github.com/knu/ruby-domain_name/compare/v0.0.0...v0.5.0)

- Implement DomainName comparison and fix cookie_domain?()
- Avoid warnings about uninitialized instance variables

## [v0.0.0](https://github.com/knu/ruby-domain_name/tree/v0.0.0) (2011-10-29)

- Initial release

\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
